@@ -16,7 +16,7 @@
 ;;;; You should have received a copy of the GNU General Public License
 ;;;; along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. 
 
-(setq mh-progs "/usr/bin")
+(setq mh-progs "/usr/bin/mu-mh")
 (setq mh-lib "/usr/share/mailutils/mh")
 (setq mh-lib-progs mh-progs)
 (load "mh-e")
